import os

def Shutdown(message, hide_message, time) -> None:
    """ Shutdown the system with a message if specified """

    if hide_message:
        os.system(f"shutdown /s /t {time}")
    else:
        os.system(f"shutdown /s /t {time} /c \"{message}\"")


import argparse

def init() -> argparse.Namespace:
    """ Initialize the arguments """

    parser = argparse.ArgumentParser(description="Shutdown On Lan")

    parser.add_argument("--port", type=int, default=8000, help="Port to run the FastAPI app on (default: 8000)")
    parser.add_argument("--message", type=str, default="The system will shut down in 5 seconds", help="Shutdown message (default: The system will shut down in 5 seconds)")
    parser.add_argument("--hide-message", action='store_true', help="Hide shutdown message if specified")
    parser.add_argument("--time", type=int, default=5, help="Time in seconds before the system shuts down (default: 5)")

    return parser.parse_args()


import argparse
from fastapi import FastAPI
import uvicorn

loggingConfig = {
    "version": 1,
    "disable_existing_loggers": False,
    "formatters": {
        "default": {
            "format": "%(asctime)s - %(levelname)s - %(message)s",
        },
    },
    "handlers": {
        "file": {
            "level": "INFO",
            "class": "logging.FileHandler",
            "filename": "server.log",
            "formatter": "default",
        },
    },
    "loggers": {
        "uvicorn": {
            "handlers": ["file"],
            "level": "INFO",
            "propagate": True,
        },
    },
}

def Server(app: FastAPI, args: argparse.Namespace) -> None:
    """ Run the FastAPI app using Uvicorn """
    
    uvicorn.run(app, host="0.0.0.0", port=args.port, log_config=loggingConfig)


from PIL import Image, ImageDraw

def CreateImage() -> Image.Image:
    """ Generate an image for the system tray icon """
    width = 64
    height = 64
    image = Image.new('RGB', (width, height), (255, 255, 255))
    dc = ImageDraw.Draw(image)
    dc.rectangle(
        (width // 2 - 10, height // 2 - 10, width // 2 + 10, height // 2 + 10),
        fill=(0, 0, 0))
    return image